@@ -1,5 +1,5 @@
 package Chart::Clicker;
-$Chart::Clicker::VERSION = '2.88';
+$Chart::Clicker::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Container';
@@ -99,7 +99,7 @@ has 'driver' => (
         )
     },
     handles => {
-        'rendered_data' => 'data',
+        rendered_data => 'data',
         write => 'write'
     },
     lazy => 1
@@ -109,21 +109,21 @@ has 'driver' => (
 has 'format' => (
     is => 'rw',
     isa => 'Str',
-    default => sub { 'PNG' }
+    default => 'PNG'
 );
 
 
 has 'plot_mode' => (
     is => 'rw',
     isa => 'Str',
-    default => sub { 'slow' }
+    default => 'slow'
 );
 
 
 has 'grid_over' => (
     is => 'rw',
     isa => 'Bool',
-    default => sub { 0 }
+    default => 0
 );
 
 
@@ -151,7 +151,7 @@ has 'legend' => (
 has 'legend_position' => (
     is => 'rw',
     isa => 'Str',
-    default => sub { 's' }
+    default => 's'
 );
 
 
@@ -219,7 +219,7 @@ has 'title' => (
 has 'title_position' => (
     is => 'rw',
     isa => 'Str',
-    default => sub { 'n' }
+    default => 'n'
 );
 
 
@@ -544,7 +544,7 @@ Chart::Clicker - Powerful, extensible charting.
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -749,7 +749,7 @@ L<Graphics::Primitive::Driver::Cairo>.
 Get the format for this Chart.  Required in the constructor.  Must be on of
 Png, Pdf, Ps or Svg.
 
-=head2 plot_mode 
+=head2 plot_mode
 
 Fast or slow plot mode. When in fast mode, data elements that are deemed to be
 superfluous or invisible will not be drawn. Default is 'slow'
@@ -1007,7 +1007,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
