@@ -1,5 +1,5 @@
 package Chart::Clicker::Data::DataSet;
-$Chart::Clicker::Data::DataSet::VERSION = '2.88';
+$Chart::Clicker::Data::DataSet::VERSION = '2.89';
 use Moose;
 
 # ABSTRACT: A collection of series
@@ -10,7 +10,7 @@ use Chart::Clicker::Data::Range;
 has 'context' => (
     is => 'rw',
     isa => 'Str',
-    default => sub { 'default'}
+    default => 'default'
 );
 
 
@@ -99,7 +99,6 @@ sub prepare {
         die('Dataset has no series.');
     }
 
-    my $stotal;
     foreach my $series (@{ $self->series }) {
         $series->prepare;
 
@@ -137,7 +136,7 @@ Chart::Clicker::Data::DataSet - A collection of series
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -226,7 +225,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
