@@ -1,5 +1,5 @@
 package Chart::Clicker::Decoration::MarkerOverlay;
-$Chart::Clicker::Decoration::MarkerOverlay::VERSION = '2.88';
+$Chart::Clicker::Decoration::MarkerOverlay::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Decoration';
@@ -24,12 +24,11 @@ override('finalize', sub {
         foreach my $marker (@{ $ctx->markers }) {
 
             my $key = $marker->key;
-            my $key2 = $marker->key2;
             my $value = $marker->value;
-            my $value2 = $marker->value2;
 
-            if($key && $value) {
-            } elsif(defined($key)) {
+            if(not defined($value)) {
+                my $key2 = $marker->key2;
+
                 my $domain = $ctx->domain_axis;
 
                 my $x = $domain->mark($self->width, $key);
@@ -60,9 +59,11 @@ override('finalize', sub {
                 $op->brush->color($marker->color);
 
                 $self->do($op);
-            } elsif(defined($value)) {
+            } elsif(not defined($key)) {
+                my $value2 = $marker->value2;
+
                 my $range = $ctx->range_axis;
-                # 
+                #
                 my $y = $height - $range->mark($height, $value);
                 my $y2;
 
@@ -113,7 +114,7 @@ Chart::Clicker::Decoration::MarkerOverlay - Component for drawing markers
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 DESCRIPTION
 
@@ -125,7 +126,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
