@@ -1,5 +1,5 @@
 package Chart::Clicker::Decoration::OverAxis;
-$Chart::Clicker::Decoration::OverAxis::VERSION = '2.88';
+$Chart::Clicker::Decoration::OverAxis::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Container';
@@ -15,7 +15,7 @@ use Layout::Manager::Flow;
 has 'axis_height' => (
     is => 'rw',
     isa => 'Num',
-    default => sub { 20 }
+    default => 20
 );
 
 
@@ -44,7 +44,7 @@ has 'border_color' => (
 has 'border_width' => (
     is => 'rw',
     isa => 'Num',
-    default => sub { 2 }
+    default => 2
 );
 
 
@@ -83,12 +83,8 @@ override('prepare', sub {
     $self->height($self->axis_height);
 
     my $ctx = $self->clicker->get_context($self->context);
-    my $domain = $ctx->domain_axis;
-
-    my $ticks = $domain->tick_values;
-    my $tick_count = scalar(@{ $ticks });
-    my $per = $self->width / $tick_count;
 
+    my $ticks = $ctx->domain_axis->tick_values;
     foreach my $tick (@{ $ticks }) {
 
         my $tb = Graphics::Primitive::TextBox->new(
@@ -120,6 +116,7 @@ override('finalize', sub {
     $self->border->top->width($self->border_width);
     $self->border->bottom->width($self->border_width);
     $self->border->color($self->border_color);
+    $self->minimum_height($self->axis_height);
     $self->height($self->axis_height);
 
     my $ticks = $domain->tick_values;
@@ -151,7 +148,7 @@ Chart::Clicker::Decoration::OverAxis - An axis drawn over data
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 DESCRIPTION
 
@@ -199,7 +196,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
