@@ -1,5 +1,5 @@
 package Chart::Clicker::Drawing::ColorAllocator;
-$Chart::Clicker::Drawing::ColorAllocator::VERSION = '2.87';
+$Chart::Clicker::Drawing::ColorAllocator::VERSION = '2.89';
 use Moose;
 
 # ABSTRACT: Color picker
@@ -37,7 +37,7 @@ has 'seed_hue' => (
     is => 'rw',
     isa => 'Int',
     required => 1,
-    default => sub { 270 },
+    default => 270,
 );
 
 
@@ -138,7 +138,7 @@ Chart::Clicker::Drawing::ColorAllocator - Color picker
 
 =head1 VERSION
 
-version 2.87
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -250,7 +250,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
