@@ -1,5 +1,5 @@
 package Chart::Clicker::Renderer::Bar;
-$Chart::Clicker::Renderer::Bar::VERSION = '2.87';
+$Chart::Clicker::Renderer::Bar::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Renderer';
@@ -68,7 +68,9 @@ override('finalize', sub {
 
     my $dses = $clicker->get_datasets_for_context($self->context);
 
-    my $padding = $self->bar_padding + $self->brush->width * 2;
+    my $brwidth = $self->brush->width;
+
+    my $padding = $self->bar_padding + $brwidth * 2;
 
     my $offset = 1;
     foreach my $ds (@{ $dses }) {
@@ -126,7 +128,7 @@ override('finalize', sub {
                             $x - $hbwidth + ($offset * $cbwidth), $basey
                         );
                         $self->rectangle(
-                            -int($cbwidth) + $self->brush->width, -int($y - ($height - $basey))
+                            -int($cbwidth) + $brwidth, -int($y - ($height - $basey))
                         );
                     }
                 } else {
@@ -140,7 +142,7 @@ override('finalize', sub {
                             $x - $hbwidth + ($offset * $cbwidth), $basey
                         );
                         $self->rectangle(
-                            -int($cbwidth) + $self->brush->width, int($height - $basey - $y)
+                            -int($cbwidth) + $brwidth, int($height - $basey - $y)
                         );
                     }
                 }
@@ -150,8 +152,6 @@ override('finalize', sub {
                 paint => Graphics::Primitive::Paint::Solid->new
             );
 
-            my $brwidth = $self->brush->width;
-
             if($self->opacity < 1) {
                 my $fillcolor = $color->clone;
                 $fillcolor->alpha($self->opacity);
@@ -196,7 +196,7 @@ Chart::Clicker::Renderer::Bar - Bar renderer
 
 =head1 VERSION
 
-version 2.87
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -244,7 +244,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
