@@ -1,5 +1,5 @@
 package Chart::Clicker::Renderer::CandleStick;
-$Chart::Clicker::Renderer::CandleStick::VERSION = '2.88';
+$Chart::Clicker::Renderer::CandleStick::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Renderer';
@@ -79,8 +79,6 @@ override('finalize', sub {
 
             my $min = $range->range->lower;
 
-            my $height = $self->height;
-
             my @highs = @{ $series->highs };
             my @lows = @{ $series->lows };
             my @opens = @{ $series->opens };
@@ -98,15 +96,15 @@ override('finalize', sub {
                 my $highy = $height - $range->mark($height, $highs[$_]);
                 my $lowy = $height - $range->mark($height, $lows[$_]);
 
-                my $height = $closey - $openy;
+                my $_height = $closey - $openy;
 
                 $self->move_to($x - $hcbwidth, $openy);
                 $self->rectangle(
-                    $cbwidth, $height
+                    $cbwidth, $_height
                 );
 
                 my $op;
-                if($height < 0) {
+                if($_height < 0) {
                     # We fill the bar if it closed higher
                     $op = Graphics::Primitive::Operation::Fill->new(
                         paint => Graphics::Primitive::Paint::Solid->new(
@@ -161,7 +159,7 @@ Chart::Clicker::Renderer::CandleStick - CandleStick renderer
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -191,7 +189,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
