@@ -1,5 +1,5 @@
 package Chart::Clicker::Renderer::PolarArea;
-$Chart::Clicker::Renderer::PolarArea::VERSION = '2.88';
+$Chart::Clicker::Renderer::PolarArea::VERSION = '2.89';
 use Moose;
 
 extends 'Chart::Clicker::Renderer';
@@ -73,8 +73,7 @@ override('prepare', sub {
         }
 
         my $count = $ds->max_key_count;
-        for(0..$count - 1) {
-            my $pos = $_;
+        for my $pos (0..$count - 1) {
             my $vals = $ds->get_series_values($pos);
             my $total = 0;
             foreach my $v (@{ $vals }) {
@@ -183,7 +182,7 @@ Chart::Clicker::Renderer::PolarArea - Polar Area renderer
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -218,7 +217,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
