@@ -1,5 +1,5 @@
 package Chart::Clicker::Renderer::StackedArea;
-$Chart::Clicker::Renderer::StackedArea::VERSION = '2.88';
+$Chart::Clicker::Renderer::StackedArea::VERSION = '2.89';
 use Moose;
 
 # ABSTRACT: Stacked Area renderer
@@ -14,7 +14,7 @@ use Graphics::Primitive::Paint::Gradient::Linear;
 use Graphics::Primitive::Paint::Solid;
 
 
-has '+additive' => ( default => sub { 1 } );
+has '+additive' => ( default => 1 );
 
 
 override('finalize', sub {
@@ -148,7 +148,7 @@ Chart::Clicker::Renderer::StackedArea - Stacked Area renderer
 
 =head1 VERSION
 
-version 2.88
+version 2.89
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cold Hard Code, LLC.
+This software is copyright (c) 2016 by Cory G Watson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
